==> ejc-zypms-impl-3.0.0-20250815.111238-131-sources.jar: com/ejianc/business/sub/service/impl/SubSettleBpmServiceImpl.java <==
package com.ejianc.business.sub.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.sub.bean.SubContractEntity;
import com.ejianc.business.sub.bean.SubSettleEntity;
import com.ejianc.business.sub.service.IContractService;
import com.ejianc.business.sub.service.ISubSettleService;
import com.ejianc.business.sub.vo.SubSettleVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 过程结算表 审批流服务实现类
 * </p>
 *
 * @author zhangwx
 * @since 2020-06-05
 */
@Service("subSettle")
public class SubSettleBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISubSettleService settleService;

    @Autowired
    private IContractService contractService;

    @Autowired
    private IBillTypeApi billTypeApi;

    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        logger.info("进入审批同意后回写--- billId:"+billId+"  state:"+state);
        SubSettleEntity settlementEntity= settleService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal sumPayMnys = settlementEntity.getSumPrepayMny()==null?BigDecimal.ZERO:settlementEntity.getSumPrepayMny();//实际预付款金额
        BigDecimal sumOffsetMnys = settlementEntity.getSumOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getSumOffsetMny();//实际累计冲抵金额
        if(offsetMny.compareTo(sumPayMnys.subtract(sumOffsetMnys))>0){
            return CommonResponse.error("审批回写异常!该合同冲抵金额已超出预付款金额!");
        }

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        SubSettleVO settleEntity = settleService.queryDetail(billId, true);
        SubContractEntity contractEntity  = contractService.getById(settleEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = settleEntity.getSettleTaxMny() == null ? BigDecimal.ZERO : settleEntity.getSettleTaxMny();
        BigDecimal settleMny = settleEntity.getSettleMny() == null ? BigDecimal.ZERO : settleEntity.getSettleMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = settleEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobTaxMny();
        BigDecimal jobMny = settleEntity.getOddjobMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = settleEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOtherTaxMny();
        BigDecimal otherMny = settleEntity.getOtherMny() == null ? BigDecimal.ZERO : settleEntity.getOtherMny();

        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();
        BigDecimal offsetMny = settleEntity.getOffsetMny()==null?BigDecimal.ZERO:settleEntity.getOffsetMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.add(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.add(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.add(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.add(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.add(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.add(otherMny));
        updateWrapper.set(SubContractEntity::getSumOffsetMny, sumOffsetMny.add(offsetMny));
        updateWrapper.eq(SubContractEntity::getId, settleEntity.getContractId());
        contractService.update(contractEntity, updateWrapper, false);

        settleService.costPush(BeanMapper.map(settleEntity, SubSettleEntity.class));
        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {

        SubSettleEntity settlementEntity = settleService.selectById(billId);
        SubContractEntity contractEntity = contractService.selectById(settlementEntity.getContractId());
        //如果合同完工结算,不允许弃审
        if (contractEntity.getFinishFlag()){
            return CommonResponse.error("该合同已经完工结算，不能回退!");
        }
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            LambdaQueryWrapper<SubSettleEntity> lambdachange = Wrappers.<SubSettleEntity>lambdaQuery();
            lambdachange.eq(SubSettleEntity::getContractId, settlementEntity.getContractId());
            lambdachange.eq(SubSettleEntity::getOrgId, settlementEntity.getOrgId());
            lambdachange.gt(SubSettleEntity::getCreateTime, settlementEntity.getCreateTime());
            lambdachange.ne(SubSettleEntity::getId,billId);
            lambdachange.in(SubSettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(),BillStateEnum.COMMITED_STATE.getBillStateCode());
            int num = settleService.count(lambdachange);
            if (num > 0) {
                return CommonResponse.error("审批回写异常!该合同不是最新的结算日期，不能回退!");
            } else {
                return CommonResponse.success();
            }
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        SubSettleVO settleEntity = settleService.queryDetail(billId, true);
        SubContractEntity contractEntity  = contractService.getById(settleEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = settleEntity.getSettleTaxMny() == null ? BigDecimal.ZERO : settleEntity.getSettleTaxMny();
        BigDecimal settleMny = settleEntity.getSettleMny() == null ? BigDecimal.ZERO : settleEntity.getSettleMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = settleEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobTaxMny();
        BigDecimal jobMny = settleEntity.getOddjobMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = settleEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOtherTaxMny();
        BigDecimal otherMny = settleEntity.getOtherMny() == null ? BigDecimal.ZERO : settleEntity.getOtherMny();

        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();
        BigDecimal offsetMny = settleEntity.getOffsetMny()==null?BigDecimal.ZERO:settleEntity.getOffsetMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.subtract(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.subtract(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.subtract(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.subtract(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.subtract(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.subtract(otherMny));
        updateWrapper.set(SubContractEntity::getSumOffsetMny, sumOffsetMny.subtract(offsetMny));
        updateWrapper.eq(SubContractEntity::getId, settleEntity.getContractId());
        contractService.update(contractEntity, updateWrapper, false);


        settleService.pullCost(billId);
        return CommonResponse.success("审批回调合同成功！");
    }

}

==> ejc-zypms-impl-3.0.0-20250821.115457-148-sources.jar: com/ejianc/business/sub/service/impl/SubSettleBpmServiceImpl.java <==
package com.ejianc.business.sub.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.sub.bean.SubContractEntity;
import com.ejianc.business.sub.bean.SubSettleEntity;
import com.ejianc.business.sub.service.IContractService;
import com.ejianc.business.sub.service.ISubSettleService;
import com.ejianc.business.sub.vo.SubSettleVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 过程结算表 审批流服务实现类
 * </p>
 *
 * @author zhangwx
 * @since 2020-06-05
 */
@Service("subSettle")
public class SubSettleBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISubSettleService settleService;

    @Autowired
    private IContractService contractService;

    @Autowired
    private IBillTypeApi billTypeApi;

    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        logger.info("进入审批同意后回写--- billId:"+billId+"  state:"+state);
        SubSettleEntity settlementEntity= settleService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal sumPayMnys = settlementEntity.getSumPrepayMny()==null?BigDecimal.ZERO:settlementEntity.getSumPrepayMny();//实际预付款金额
        BigDecimal sumOffsetMnys = settlementEntity.getSumOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getSumOffsetMny();//实际累计冲抵金额
        if(offsetMny.compareTo(sumPayMnys.subtract(sumOffsetMnys))>0){
            return CommonResponse.error("审批回写异常!该合同冲抵金额已超出预付款金额!");
        }

        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        SubSettleVO settleEntity = settleService.queryDetail(billId, true);
        SubContractEntity contractEntity  = contractService.getById(settleEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = settleEntity.getSettleTaxMny() == null ? BigDecimal.ZERO : settleEntity.getSettleTaxMny();
        BigDecimal settleMny = settleEntity.getSettleMny() == null ? BigDecimal.ZERO : settleEntity.getSettleMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = settleEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobTaxMny();
        BigDecimal jobMny = settleEntity.getOddjobMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = settleEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOtherTaxMny();
        BigDecimal otherMny = settleEntity.getOtherMny() == null ? BigDecimal.ZERO : settleEntity.getOtherMny();

        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();
        BigDecimal offsetMny = settleEntity.getOffsetMny()==null?BigDecimal.ZERO:settleEntity.getOffsetMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.add(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.add(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.add(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.add(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.add(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.add(otherMny));
        updateWrapper.set(SubContractEntity::getSumOffsetMny, sumOffsetMny.add(offsetMny));
        updateWrapper.eq(SubContractEntity::getId, settleEntity.getContractId());
        contractService.update(updateWrapper);

        settleService.costPush(BeanMapper.map(settleEntity, SubSettleEntity.class));
        return CommonResponse.success("审批回调合同成功！");
    }

    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {

        SubSettleEntity settlementEntity = settleService.selectById(billId);
        SubContractEntity contractEntity = contractService.selectById(settlementEntity.getContractId());
        //如果合同完工结算,不允许弃审
        if (contractEntity.getFinishFlag()){
            return CommonResponse.error("该合同已经完工结算，不能回退!");
        }
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            LambdaQueryWrapper<SubSettleEntity> lambdachange = Wrappers.<SubSettleEntity>lambdaQuery();
            lambdachange.eq(SubSettleEntity::getContractId, settlementEntity.getContractId());
            lambdachange.eq(SubSettleEntity::getOrgId, settlementEntity.getOrgId());
            lambdachange.gt(SubSettleEntity::getCreateTime, settlementEntity.getCreateTime());
            lambdachange.ne(SubSettleEntity::getId,billId);
            lambdachange.in(SubSettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(),BillStateEnum.COMMITED_STATE.getBillStateCode());
            int num = settleService.count(lambdachange);
            if (num > 0) {
                return CommonResponse.error("审批回写异常!该合同不是最新的结算日期，不能回退!");
            } else {
                return CommonResponse.success();
            }
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        SubSettleVO settleEntity = settleService.queryDetail(billId, true);
        SubContractEntity contractEntity  = contractService.getById(settleEntity.getContractId());

        BigDecimal sumSettleTaxMny = contractEntity.getSumSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleTaxMny();
        BigDecimal sumSettleMny = contractEntity.getSumSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumSettleMny();
        BigDecimal settleTaxMny = settleEntity.getSettleTaxMny() == null ? BigDecimal.ZERO : settleEntity.getSettleTaxMny();
        BigDecimal settleMny = settleEntity.getSettleMny() == null ? BigDecimal.ZERO : settleEntity.getSettleMny();

        BigDecimal sumOddjobSettleTaxMny = contractEntity.getSumOddjobSettleTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleTaxMny();
        BigDecimal sumOddjobSettleMny = contractEntity.getSumOddjobSettleMny() == null ? BigDecimal.ZERO : contractEntity.getSumOddjobSettleMny();
        BigDecimal jobTaxMny = settleEntity.getOddjobTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobTaxMny();
        BigDecimal jobMny = settleEntity.getOddjobMny() == null ? BigDecimal.ZERO : settleEntity.getOddjobMny();

        BigDecimal sumOtherTaxMny = contractEntity.getSumOtherTaxMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherTaxMny();
        BigDecimal sumOtherMny = contractEntity.getSumOtherMny() == null ? BigDecimal.ZERO : contractEntity.getSumOtherMny();
        BigDecimal otherTaxMny = settleEntity.getOtherTaxMny() == null ? BigDecimal.ZERO : settleEntity.getOtherTaxMny();
        BigDecimal otherMny = settleEntity.getOtherMny() == null ? BigDecimal.ZERO : settleEntity.getOtherMny();

        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();
        BigDecimal offsetMny = settleEntity.getOffsetMny()==null?BigDecimal.ZERO:settleEntity.getOffsetMny();

        LambdaUpdateWrapper<SubContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.set(SubContractEntity::getSumSettleTaxMny, sumSettleTaxMny.subtract(settleTaxMny));
        updateWrapper.set(SubContractEntity::getSumSettleMny, sumSettleMny.subtract(settleMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleTaxMny, sumOddjobSettleTaxMny.subtract(jobTaxMny));
        updateWrapper.set(SubContractEntity::getSumOddjobSettleMny, sumOddjobSettleMny.subtract(jobMny));
        updateWrapper.set(SubContractEntity::getSumOtherTaxMny, sumOtherTaxMny.subtract(otherTaxMny));
        updateWrapper.set(SubContractEntity::getSumOtherMny, sumOtherMny.subtract(otherMny));
        updateWrapper.set(SubContractEntity::getSumOffsetMny, sumOffsetMny.subtract(offsetMny));
        updateWrapper.eq(SubContractEntity::getId, settleEntity.getContractId());
        contractService.update(updateWrapper);


        settleService.pullCost(billId);
        return CommonResponse.success("审批回调合同成功！");
    }

}
